Package: funMoDisco
Type: Package
Title: Motif Discovery in Functional Data
Version: 1.1.5
Date: 2026-04-21
Authors@R: c(
    person(given = c("Marzia", "Angela"), family = "Cremona", role = "aut"),
    person(given = "Francesca", family = "Chiaromonte", role = "aut"),
    person(given = "Jacopo", family = "Di Iorio", role = c("aut", "cre"), 
           email = "jacopo.di.iorio@emory.edu"),
    person(given = "Niccolò", family = "Feresini", role = "aut"),
    person(given = "Riccardo", family = "Lazzarini", role = "aut"))
Author: Marzia Angela Cremona [aut],
  Francesca Chiaromonte [aut],
  Jacopo Di Iorio [aut, cre],
  Niccolò Feresini [aut],
  Riccardo Lazzarini [aut]
Maintainer: Jacopo Di Iorio <jacopo.di.iorio@emory.edu>
Description: Efficiently implementing two complementary methodologies for discovering motifs in functional data: ProbKMA and FunBIalign. 
    Cremona and Chiaromonte (2023) "Probabilistic K-means with Local Alignment for Clustering and Motif Discovery in Functional Data" <doi:10.1080/10618600.2022.2156522> is a probabilistic K-means algorithm that leverages local alignment and fuzzy clustering to identify recurring patterns (candidate functional motifs) across and within curves, allowing different portions of the same curve to belong to different clusters. It includes a family of distances and a normalization to discover various motif types and learns motif lengths in a data-driven manner. It can also be used for local clustering of misaligned data.
    Di Iorio, Cremona, and Chiaromonte (2023) "funBIalign: A Hierarchical Algorithm for Functional Motif Discovery Based on Mean Squared Residue Scores" <doi:10.48550/arXiv.2306.04254> applies hierarchical agglomerative clustering with a functional generalization of the Mean Squared Residue Score to identify motifs of a specified length in curves. This deterministic method includes a small set of user-tunable parameters.
    Both algorithms are suitable for single curves or sets of curves. The package also includes a flexible function to simulate functional data with embedded motifs, allowing users to generate benchmark datasets for validating and comparing motif discovery methods.
License: GPL (>= 2)
Suggests: knitr, rmarkdown, tinytest, kableExtra, R.rsp
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: Rcpp (>= 1.0.12),dendextend,fastcluster,
        fda,ggtext,methods,purrr,scales,
        utils,class,combinat,data.table,stringr
Depends: R (>= 3.5.0),dplyr,parallel,ggplot2,progress
LinkingTo: Rcpp, RcppArmadillo
SystemRequirements: C++20
LazyData: true
VignetteBuilder: R.rsp
BuildVignettes: true
Language: en-US
NeedsCompilation: yes
Packaged: 2026-04-22 00:33:44 UTC; jqd5830
Repository: CRAN
Date/Publication: 2026-04-22 02:50:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 13:00:59 UTC; unix
Archs: funMoDisco.so.dSYM
