# Generated by roxygen2: do not edit by hand

export(.check_fits)
export(.diss_d0_d1_L2)
export(.domain)
export(.find_min_diss)
export(.find_occurrences)
export(.generate_coefficients)
export(.mapply_custom)
export(.resample)
export(.select_domain)
export(.transform_list)
export(.transform_to_matrix)
export(ProbKMA)
export(add_error_to_motif)
export(add_motif)
export(cluster_candidate_motifs)
export(cluster_candidate_motifs_plot)
export(compare_nodes)
export(discoverMotifs)
export(filter_candidate_motifs)
export(find_recommended_path)
export(generate_background_curve)
export(generate_curve_vector)
export(get_accolites)
export(get_minidend)
export(get_parents)
export(get_path_complete)
export(initialChecks)
export(motifSimulationBuilder)
export(motifs_search)
export(motifs_search_plot)
export(padding)
export(plot_motifs)
export(probKMA_plot)
export(probKMA_silhouette_filter)
export(probKMA_silhouette_plot)
export(probKMA_wrap)
export(recommend_node)
export(to_motifDiscovery)
exportClasses(motifSimulation)
exportMethods(generateCurves)
exportMethods(plot_motifs)
exportMethods(to_motifDiscovery)
import(Rcpp)
import(dendextend)
import(dplyr)
import(ggplot2)
import(grDevices)
import(graphics)
import(methods)
import(parallel)
importFrom(Rcpp,evalCpp)
importFrom(class,knn)
importFrom(combinat,combn)
importFrom(data.table,as.data.table)
importFrom(data.table,setnames)
importFrom(dplyr,"%>%")
importFrom(fastcluster,hclust)
importFrom(fda,create.bspline.basis)
importFrom(fda,eval.fd)
importFrom(fda,fd)
importFrom(fda,smooth.basis)
importFrom(ggtext,element_markdown)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grDevices,rainbow)
importFrom(progress,progress_bar)
importFrom(purrr,is_empty)
importFrom(stats,as.dendrogram)
importFrom(stats,as.dist)
importFrom(stats,density)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(stats,rbeta)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,start)
importFrom(stats,var)
importFrom(utils,modifyList)
importFrom(utils,tail)
useDynLib(funMoDisco, .registration = TRUE)
