globalVariables(c("pos", "window_data", "probKMA_results", "silhouette", "y", "depth_order", 
                  "xmin", "xmax", "initial_number", "SNR", "instance", "motif_id", 
                  "sd_noise", "start_break_pos", "Y0_inters_k","createWindow", "createDistance", "deleteV", "fMSR_adj", "ProbKMA", "sd_noise"))