#' @title High Dimensional simulated data for local clustering 
#'
#' @description
#' The functional dataset consists of 43 matrices for curves and an equal number 
#' for their derivatives of two columns and a variable number of rows ranging 
#' from a minimum of 1836 to a maximum of 43868. The data presents 
#' a lot of missing values (large gaps).
#' @name simulatedHighDimensional
#' @usage data(simulatedHighDimensional)
"simulatedHighDimensional"